import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { groupBy, toArray, mergeMap, tap, mergeAll, map } from 'rxjs/operators';

import { DataService } from '@app/core/data.service';


@Injectable({
	providedIn: 'root'
})
export class DegreePlannerDataService {
	degreePlannerData: Observable<any>;
	coursesData$: any;

	constructor(private dataService: DataService) { }

	getDegreePlanDataById(planId: number) {
		this.degreePlannerData = this.dataService.getDegreePlannerCourseData(planId).pipe(
			map(courses => courses.sort((a, b) => Number(a.termCode) - Number(b.termCode))),
			mergeAll()
		);

		this.coursesData$ = this.degreePlannerData.pipe(
			groupBy(course => course.termCode),
			mergeMap(group$ => group$.pipe(toArray())),
			map(course => {
				return {
					termCode: course[0].termCode,
					year: course[0].termCode.substring(1, 3),
					courses: course.slice(1)
				};
			}),
			groupBy(terms => terms.year),
			mergeMap(group$ => group$.pipe(toArray())),
			toArray(),

			tap(x => console.log('new data', x))
		);

		return this.coursesData$;
	}

	getDegreePlanData() {
		return this.coursesData$;
	}
}



